translate_function_body

Function translate_function_body 

pub fn translate_function_body(
    target: &TargetSpec,
    module: &[Stmt],
) -> Option<Translation>
Find and translate the body of the named function in module.

Returns None only if the function is not found. Returns a Translation with fallback: true if the body cannot be translated.