Module utils

Module utils 

Structs

AccelerateRow
One row in the post-generation summary table printed to stdout.
GenerationResult
Hotspot
ProfileSummary
TargetSpec

Enums

InputSource

Functions

extract_code
materialize_input
Materialize the input source into a concrete file path for profiling/build steps. Returns the path and a TempDir to keep the file alive for the caller’s scope.
print_hotspot_table
Print a hotspot table to stdout (used by –list-targets).
print_summary
Print a simple ASCII summary table to stdout.