materialize_input

Function materialize_input 

pub fn materialize_input(source: &InputSource) -> Result<(PathBuf, TempDir)>
Materialize the input source into a concrete file path for profiling/build steps. Returns the path and a TempDir to keep the file alive for the caller’s scope.