Structs
- Accelerate
Row - One row in the post-generation summary table printed to stdout.
- Generation
Result - Hotspot
- Profile
Summary - Target
Spec
Enums
Functions
- extract_
code - materialize_
input - Materialize the input source into a concrete file path for profiling/build steps. Returns the path and a TempDir to keep the file alive for the caller’s scope.
- print_
hotspot_ table - Print a hotspot table to stdout (used by –list-targets).
- print_
summary - Print a simple ASCII summary table to stdout.